Stan Math Library: stan/math/rev/scal/fun/inv_logit.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

inv_logit.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_INV_LOGIT_HPP
2 #define STAN_MATH_REV_SCAL_FUN_INV_LOGIT_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/fun/inv_logit.hpp>
6
7 namespace stan {
8 namespace math {
9
10 namespace {
11 class inv_logit_vari : public op_v_vari {
12 public:
13 explicit inv_logit_vari(vari* avi) :
14 op_v_vari(stan::math::inv_logit(avi->val_), avi) {
15 }
16 void chain() {
17 avi_->adj_ += adj_ * val_ * (1.0 - val_);
18 }
19 };
20 }
21
34 inline var inv_logit(const stan::math::var& a) {
35 return var(new inv_logit_vari(a.vi_));
36 }
37
38 }
39 }
40 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::inv_logit
fvar< T > inv_logit(const fvar< T > &x)
Definition: inv_logit.hpp:15
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
inv_logit.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.